@@ -254,17 +254,6 @@ static int radius_auth_pass(void *ctx, const char *pass, unsigned pass_len)
 		goto cleanup;
 	}
 
-	if (pctx->id) {
-		service = pctx->id;
-		if (rc_avpair_add(rh, &send, PW_NAS_PORT, &service, -1, 0) == NULL) {
-			syslog(LOG_ERR,
-			       "%s:%u: error in constructing radius message for user '%s'", __func__, __LINE__,
-			       pctx->username);
-			ret = ERR_AUTH_FAIL;
-			goto cleanup;
-		}
-	}
-
 	service = PW_ASYNC;
 	if (rc_avpair_add(rh, &send, PW_NAS_PORT_TYPE, &service, -1, 0) == NULL) {
 		syslog(LOG_ERR,
@@ -274,7 +263,7 @@ static int radius_auth_pass(void *ctx, const char *pass, unsigned pass_len)
 		goto cleanup;
 	}
 
-	ret = rc_aaa(rh, 0, send, &recvd, NULL, 1, PW_ACCESS_REQUEST);
+	ret = rc_aaa(rh, pctx->id, send, &recvd, NULL, 1, PW_ACCESS_REQUEST);
 
 	if (ret == OK_RC) {
 		VALUE_PAIR *vp = recvd;
