@@ -33,7 +33,6 @@
 #include <c-ctype.h>
 #include <auth/pam.h>
 #include <auth/radius.h>
-#include <acct/pam.h>
 #include <acct/radius.h>
 #include <auth/plain.h>
 #include <auth/gssapi.h>
@@ -56,7 +55,7 @@
 #define DEFAULT_CFG_FILE "/etc/ocserv/ocserv.conf"
 
 static char pid_file[_POSIX_PATH_MAX] = "";
-static const char* cfg_file = DEFAULT_CFG_FILE;
+static char cfg_file[_POSIX_PATH_MAX] = DEFAULT_CFG_FILE;
 
 struct cfg_options {
 	const char* name;
@@ -76,6 +75,7 @@ static struct cfg_options available_options[] = {
 	{ .name = "acct", .type = OPTION_STRING, .mandatory = 0 },
 	{ .name = "listen-host", .type = OPTION_STRING, .mandatory = 0 },
 	{ .name = "listen-host-is-dyndns", .type = OPTION_BOOLEAN, .mandatory = 0 },
+	{ .name = "listen-proxy-proto", .type = OPTION_BOOLEAN, .mandatory = 0 },
 	{ .name = "compression", .type = OPTION_BOOLEAN, .mandatory = 0 },
 	{ .name = "no-compress-limit", .type = OPTION_NUMERIC, .mandatory = 0 },
 	{ .name = "tcp-port", .type = OPTION_NUMERIC, .mandatory = 0 },
@@ -233,9 +233,12 @@ unsigned j;
 
 #define PREAD_STRING(pool, name, s_name) { \
 	val = get_option(name, &mand); \
-	if (val != NULL && val->valType == OPARG_TYPE_STRING) \
-		s_name = talloc_strdup(pool, val->v.strVal); \
-	else if (mand != 0) { \
+	if (val != NULL && val->valType == OPARG_TYPE_STRING) { \
+		unsigned len = strlen(val->v.strVal); \
+		while(c_isspace(val->v.strVal[len-1])) \
+			len--; \
+		s_name = talloc_strndup(pool, val->v.strVal, len); \
+	} else if (mand != 0) { \
 		fprintf(stderr, "Configuration option %s is mandatory.\n", name); \
 		exit(1); \
 	}}
@@ -460,12 +463,10 @@ typedef struct acct_types_st {
 
 static acct_types_st avail_acct_types[] =
 {
-#ifdef HAVE_PAM
-	{NAME("pam"), &pam_acct_funcs, NULL},
-#endif
 #ifdef HAVE_RADIUS
 	{NAME("radius"), &radius_acct_funcs, radius_get_brackets_string},
 #endif
+	{NAME("pam"), NULL, NULL}
 };
 
 static void figure_acct_funcs(struct perm_cfg_st *config, const char *acct)
@@ -476,6 +477,9 @@ static void figure_acct_funcs(struct perm_cfg_st *config, const char *acct)
 	/* Set the accounting method */
 	for (i=0;i<sizeof(avail_acct_types)/sizeof(avail_acct_types[0]);i++) {
 		if (c_strncasecmp(acct, avail_acct_types[i].name, avail_acct_types[i].name_size) == 0) {
+			if (avail_acct_types[i].mod == NULL)
+				continue;
+
 			if (avail_acct_types[i].get_brackets_string)
 				config->acct.additional = avail_acct_types[i].get_brackets_string(config, acct+avail_acct_types[i].name_size);
 
@@ -677,6 +681,7 @@ size_t urlfw_size = 0;
 	 * reload_cfg_file();
 	 */
 	READ_TF("listen-host-is-dyndns", config->is_dyndns, 0);
+	READ_TF("listen-proxy-proto", config->listen_proxy_proto, 0);
 
 #ifdef HAVE_GSSAPI
 	READ_MULTI_LINE("kkdcp", urlfw, urlfw_size);
@@ -975,8 +980,10 @@ static void check_cfg(struct perm_cfg_st *perm_config)
 	}
 
 	if (perm_config->unix_conn_file != NULL && (perm_config->config->cert_req != 0)) {
-		fprintf(stderr, "The option 'listen-clear-file' cannot be combined with 'auth=certificate'\n");
-		exit(1);
+		if (perm_config->config->listen_proxy_proto == 0) {
+			fprintf(stderr, "The option 'listen-clear-file' cannot be combined with 'auth=certificate'\n");
+			exit(1);
+		}
 	}
 
 #ifdef ANYCONNECT_CLIENT_COMPAT
@@ -1037,7 +1044,7 @@ int cmd_parser (void *pool, int argc, char **argv, struct perm_cfg_st** config)
 		(*config)->config->debug = OPT_VALUE_DEBUG;
 
 	if (HAVE_OPT(CONFIG)) {
-		cfg_file = OPT_ARG(CONFIG);
+		strlcpy(cfg_file, OPT_ARG(CONFIG), sizeof(cfg_file));
 	} else if (access(cfg_file, R_OK) != 0) {
 		fprintf(stderr, "%s -c [config]\nUse %s --help for more information.\n", argv[0], argv[0]);
 		exit(1);
