@@ -92,7 +92,21 @@ int send_cookie_auth_reply(main_server_st* s, struct proc_st* proc,
 		msg.ipv4_network = proc->config.ipv4_network;
 		msg.ipv6_network = proc->config.ipv6_network;
 
-		msg.ipv6_prefix = proc->config.ipv6_prefix;
+		if (proc->ipv6) {
+			msg.ipv6_prefix = proc->ipv6->prefix;
+			msg.has_ipv6_prefix = 1;
+		}
+
+		if (proc->config.interim_update_secs) {
+			msg.has_interim_update_secs = 1;
+			msg.interim_update_secs = proc->config.interim_update_secs;
+		}
+
+		if (proc->config.session_timeout_secs) {
+			msg.has_session_timeout_secs = 1;
+			msg.session_timeout_secs = proc->config.session_timeout_secs;
+		}
+
 		if (proc->config.rx_per_sec != 0) {
 			msg.has_rx_per_sec = 1;
 			msg.rx_per_sec = proc->config.rx_per_sec;
