@@ -110,8 +110,10 @@ int ctl_handler_init(main_server_st * s)
 	struct sockaddr_un sa;
 	int sd, e;
 
-	if (s->config->use_occtl == 0 || s->perm_config->occtl_socket_file == NULL)
+	if (s->config->use_occtl == 0 || s->perm_config->occtl_socket_file == NULL) {
+		mslog(s, NULL, LOG_INFO, "not using control unix socket");
 		return 0;
+	}
 
 	mslog(s, NULL, LOG_DEBUG, "initializing control unix socket: %s", s->perm_config->occtl_socket_file);
 	memset(&sa, 0, sizeof(sa));
@@ -264,6 +266,17 @@ static int append_user_info(method_ctx *ctx,
 		strtmp = "";
 	rep->ip = strtmp;
 
+	ipbuf = talloc_size(ctx->pool, IPBUF_SIZE);
+	if (ipbuf == NULL)
+		return -1;
+
+	strtmp =
+	    human_addr2((struct sockaddr *)&ctmp->our_addr,
+			ctmp->our_addr_len, ipbuf, IPBUF_SIZE, 0);
+	if (strtmp == NULL)
+		strtmp = "";
+	rep->local_dev_ip = strtmp;
+
 	rep->tun = ctmp->tun_lease.name;
 
 	ipbuf = talloc_size(ctx->pool, IPBUF_SIZE);
@@ -360,6 +373,9 @@ static int append_user_info(method_ctx *ctx,
 	tmp *= 1000;
 	rep->tx_per_sec = tmp;
 
+	rep->domains = ctx->s->config->split_dns;
+	rep->n_domains = ctx->s->config->split_dns_size;
+
 	if (ctmp->config.dns_size > 0) {
 		rep->dns = ctmp->config.dns;
 		rep->n_dns = ctmp->config.dns_size;
