@@ -69,6 +69,9 @@ extern const ASN1_ARRAY_TYPE kkdcp_asn1_tab[];
 ASN1_TYPE _kkdcp_pkix1_asn = ASN1_TYPE_EMPTY;
 #endif
 
+int saved_argc = 0;
+char **saved_argv = NULL;
+
 int syslog_open = 0;
 static unsigned int terminate = 0;
 static unsigned int reload_conf = 0;
@@ -130,10 +133,12 @@ int y;
 		       (const void *)&y, sizeof(y)) < 0)
 		perror("setsockopt(IP_PKTINFO) failed");
 #elif defined(IP_RECVDSTADDR) /* *BSD */
-	y = 1;
-	if (setsockopt(fd, IPPROTO_IP, IP_RECVDSTADDR,
-		       (const void *)&y, sizeof(y)) < 0)
-		perror("setsockopt(IP_RECVDSTADDR) failed");
+	if (family == AF_INET) {
+		y = 1;
+		if (setsockopt(fd, IPPROTO_IP, IP_RECVDSTADDR,
+			       (const void *)&y, sizeof(y)) < 0)
+			perror("setsockopt(IP_RECVDSTADDR) failed");
+	}
 #endif
 #if defined(IPV6_RECVPKTINFO)
 	if (family == AF_INET6) {
@@ -935,6 +940,9 @@ int main(int argc, char** argv)
 	talloc_enable_leak_report_full();
 #endif
 
+	saved_argc = argc;
+	saved_argv = argv;
+
 	memset(&creds, 0, sizeof(creds));
 
 	/* main pool */
@@ -1175,9 +1183,16 @@ int main(int argc, char** argv)
 					break;
 				}
 
-				if (check_if_banned(s, &ws->remote_addr, ws->remote_addr_len) != 0) {
-					close(fd);
-					break;
+				if (ws->conn_type != SOCK_TYPE_UNIX && !s->config->listen_proxy_proto) {
+					memset(&ws->our_addr, 0, sizeof(ws->our_addr));
+					ws->our_addr_len = sizeof(ws->our_addr);
+					if (getsockname(fd, (struct sockaddr*)&ws->our_addr, &ws->our_addr_len) < 0)
+						ws->our_addr_len = 0;
+
+					if (check_if_banned(s, &ws->remote_addr, ws->remote_addr_len) != 0) {
+						close(fd);
+						break;
+					}
 				}
 
 				/* Create a command socket */
@@ -1243,6 +1258,7 @@ fork_failed:
 					/* add_proc */
 					ctmp = new_proc(s, pid, cmd_fd[0], 
 							&ws->remote_addr, ws->remote_addr_len,
+							&ws->our_addr, ws->our_addr_len,
 							ws->sid, sizeof(ws->sid));
 					if (ctmp == NULL) {
 						kill(pid, SIGTERM);
