@@ -254,7 +254,7 @@ int handle_status_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *para
 	print_single_value_int(stdout, params, "TLS DB entries", rep->stored_tls_sessions, 1);
 	print_separator(stdout, params);
 	print_single_value_int(stdout, params, "Server PID", rep->pid, 1);
-	print_single_value_int(stdout, params, "Sec-mod PID", rep->sec_mod_pid, 1);
+	print_single_value_int(stdout, params, "Sec-mod PID", rep->sec_mod_pid, 0);
 	print_end_block(stdout, params, 0);
 
 	status_rep__free_unpacked(rep, &pa);
@@ -542,7 +542,7 @@ int handle_list_users_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st *
 
 	entries_clear();
 
-	out = pager_start();
+	out = pager_start(params);
 
 	ret = send_cmd(ctx, CTL_CMD_LIST, NULL, NULL, NULL, &raw);
 	if (ret < 0) {
@@ -633,7 +633,7 @@ int handle_list_banned_cmd(struct unix_ctx *ctx, const char *arg, cmd_params_st
 
 	ip_entries_clear();
 
-	out = pager_start();
+	out = pager_start(params);
 
 	ret = send_cmd(ctx, CTL_CMD_LIST_BANNED, NULL, NULL, NULL, &raw);
 	if (ret < 0) {
@@ -750,7 +750,7 @@ int common_info_cmd(UserListRep * args, FILE *out, cmd_params_st *params)
 	unsigned init_pager = 0;
 
 	if (out == NULL) {
-		out = pager_start();
+		out = pager_start(params);
 		init_pager = 1;
 	}
 
@@ -779,7 +779,12 @@ int common_info_cmd(UserListRep * args, FILE *out, cmd_params_st *params)
 			groupname = NO_GROUP;
 
 		print_pair_value(out, params, "Username", username, "Groupname", groupname, 1);
-		print_pair_value(out, params, "State", args->user[i]->status, "Remote IP", args->user[i]->ip, 1);
+		print_single_value(out, params, "State", args->user[i]->status, 1);
+		if (args->user[i]->has_mtu != 0)
+			print_pair_value(out, params, "Device", args->user[i]->tun, "MTU", int2str(tmpbuf, args->user[i]->mtu), 1);
+		else
+			print_single_value(out, params, "Device", args->user[i]->tun, 1);
+		print_pair_value(out, params, "Remote IP", args->user[i]->ip, "Local Device IP", args->user[i]->local_dev_ip, 1);
 
 		if (args->user[i]->local_ip != NULL && args->user[i]->local_ip[0] != 0 &&
 		    args->user[i]->remote_ip != NULL && args->user[i]->remote_ip[0] != 0) {
@@ -790,11 +795,6 @@ int common_info_cmd(UserListRep * args, FILE *out, cmd_params_st *params)
 			print_pair_value(out, params, "IPv6", args->user[i]->local_ip6, "P-t-P IPv6", args->user[i]->remote_ip6, 1);
 		}
 
-		if (args->user[i]->has_mtu != 0)
-			print_pair_value(out, params, "Device", args->user[i]->tun, "MTU", int2str(tmpbuf, args->user[i]->mtu), 1);
-		else
-			print_single_value(out, params, "Device", args->user[i]->tun, 1);
-
 		print_single_value(out, params, "User-Agent", args->user[i]->user_agent, 1);
 
 		if (args->user[i]->rx_per_sec > 0 || args->user[i]->tx_per_sec > 0) {
@@ -835,6 +835,9 @@ int common_info_cmd(UserListRep * args, FILE *out, cmd_params_st *params)
 		if (print_list_entries(out, params, "NBNS", args->user[i]->nbns, args->user[i]->n_nbns, 1) < 0)
 			goto error_parse;
 
+		if (print_list_entries(out, params, "Split-DNS-Domains", args->user[i]->domains, args->user[i]->n_domains, 1) < 0)
+			goto error_parse;
+
 		if ((r = print_list_entries(out, params, "Routes", args->user[i]->routes, args->user[i]->n_routes, 1)) < 0)
 			goto error_parse;
 		if (r == 0) {
