@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2013, 2014 Nikos Mavrogiannopoulos
+ * Copyright (C) 2013, 2014, 2015 Nikos Mavrogiannopoulos
+ * Copyright (C) 2015 Red Hat, Inc.
  *
  * This file is part of ocserv.
  *
@@ -33,7 +34,6 @@
 #include <unistd.h>
 #include <limits.h>
 #include <netinet/in.h>
-#include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/tcp.h>
 #include <arpa/inet.h>
@@ -46,9 +46,8 @@
 #include <c-ctype.h>
 #include <worker-bandwidth.h>
 
-#ifdef __linux__
-/* for IPV6_PATHMTU */
-# include <linux/in6.h>
+#if defined(__linux__) &&!defined(IPV6_PATHMTU)
+# define IPV6_PATHMTU 61
 #endif
 
 #include <vpn.h>
@@ -88,10 +87,9 @@ static int parse_cstp_data(struct worker_st *ws, uint8_t * buf, size_t buf_size,
 static int parse_dtls_data(struct worker_st *ws, uint8_t * buf, size_t buf_size,
 			   time_t);
 void exit_worker(worker_st * ws);
-
 static void exit_worker_reason(worker_st * ws, unsigned reason);
-
 static int connect_handler(worker_st * ws);
+static void session_info_send(worker_st * ws);
 
 static void handle_alarm(int signo)
 {
@@ -374,6 +372,7 @@ static void exit_worker_reason(worker_st * ws, unsigned reason)
 	exit(1);
 }
 
+
 /* vpn_server:
  * @ws: an initialized worker structure
  *
@@ -423,12 +422,23 @@ void vpn_server(struct worker_st *ws)
 	}
 	ws->session_start_time = ws->last_stats_msg = time(0);
 
-	oclog(ws, LOG_DEBUG, "accepted connection");
 	if (ws->remote_addr_len == sizeof(struct sockaddr_in))
 		ws->proto = AF_INET;
 	else
 		ws->proto = AF_INET6;
 
+	if (ws->config->listen_proxy_proto) {
+		oclog(ws, LOG_DEBUG, "accepted proxy protocol connection");
+		ret = parse_proxy_proto_header(ws, ws->conn_fd);
+		if (ret < 0) {
+			oclog(ws, LOG_ERR,
+			      "could not parse proxy protocol header; discarding connection");
+			exit_worker(ws);
+		}
+	} else {
+		oclog(ws, LOG_DEBUG, "accepted connection");
+	}
+
 	if (ws->conn_type != SOCK_TYPE_UNIX) {
 		/* initialize the session */
 		ret = gnutls_init(&session, GNUTLS_SERVER);
@@ -461,6 +471,7 @@ void vpn_server(struct worker_st *ws)
 	} else {
 		oclog(ws, LOG_DEBUG, "Accepted unix connection");
 	}
+	session_info_send(ws);
 
 	memset(&settings, 0, sizeof(settings));
 
@@ -478,6 +489,10 @@ void vpn_server(struct worker_st *ws)
 
 	human_addr2((void*)&ws->remote_addr, ws->remote_addr_len, ws->remote_ip_str, sizeof(ws->remote_ip_str), 0);
 
+	if (ws->config->listen_proxy_proto) {
+		oclog(ws, LOG_DEBUG, "proxy-hdr: peer is %s\n", ws->remote_ip_str);
+	}
+
 	ws->session = session;
 	ws->parser = &parser;
 
@@ -607,6 +622,15 @@ void session_info_send(worker_st * ws)
 		msg.user_agent = ws->req.user_agent;
 	}
 
+	if (ws->config->listen_proxy_proto) {
+		msg.our_addr.data = (uint8_t*)&ws->our_addr;
+		msg.our_addr.len = ws->our_addr_len;
+		msg.has_our_addr = 1;
+		msg.remote_addr.data = (uint8_t*)&ws->remote_addr;
+		msg.remote_addr.len = ws->remote_addr_len;
+		msg.has_remote_addr = 1;
+	}
+
 	send_msg_to_main(ws, CMD_SESSION_INFO, &msg,
 			 (pack_size_func) session_info_msg__get_packed_size,
 			 (pack_func) session_info_msg__pack);
@@ -729,14 +753,27 @@ void mtu_ok(worker_st * ws)
 	return;
 }
 
+#define FUZZ(x, diff, rnd) \
+		if (x > diff) { \
+			int16_t r = rnd; \
+			x += r % diff; \
+		}
+
 static
-int periodic_check(worker_st * ws, unsigned mtu_overhead, time_t now,
+int periodic_check(worker_st * ws, unsigned mtu_overhead, struct timespec *tnow,
 		   unsigned dpd)
 {
 	socklen_t sl;
 	int max, e, ret;
+	time_t now = tnow->tv_sec;
+	time_t periodic_check_time = PERIODIC_CHECK_TIME;
 
-	if (now - ws->last_periodic_check < PERIODIC_CHECK_TIME)
+	/* modify timers with a fuzzying factor, to prevent all worker processes
+	 * to act at exactly the same time (e.g., after a server restart on which
+	 * all clients reconnect at the same time). */
+	FUZZ(periodic_check_time, 5, tnow->tv_nsec);
+
+	if (now - ws->last_periodic_check < periodic_check_time)
 		return 0;
 
 	if (ws->config->idle_timeout > 0) {
@@ -1297,6 +1334,7 @@ static int connect_handler(worker_st * ws)
 	fd_set rfds;
 	int e, max, ret, t;
 	char *p;
+	unsigned rnd;
 #ifdef HAVE_PSELECT
 	struct timespec tv;
 #else
@@ -1312,6 +1350,8 @@ static int connect_handler(worker_st * ws)
 	sigemptyset(&emptyset);
 	sigaddset(&blockset, SIGTERM);
 
+	gnutls_rnd(GNUTLS_RND_NONCE, &rnd, sizeof(rnd));
+
 	ws->buffer_size = sizeof(ws->buffer);
 
 	/* we must be in S_AUTH_COOKIE state */
@@ -1368,6 +1408,9 @@ static int connect_handler(worker_st * ws)
 		return -1;
 	}
 
+	FUZZ(ws->config->stats_report_time, 5, rnd);
+	FUZZ(ws->config->rekey_time, 30, rnd);
+
 	/* Connected. Turn of the alarm */
 	if (ws->config->auth_timeout)
 		alarm(0);
@@ -1822,7 +1865,6 @@ static int connect_handler(worker_st * ws)
 	bandwidth_init(&ws->b_rx, ws->config->rx_per_sec);
 	bandwidth_init(&ws->b_tx, ws->config->tx_per_sec);
 
-	session_info_send(ws);
 	sigprocmask(SIG_BLOCK, &blockset, NULL);
 
 	/* worker main loop  */
@@ -1894,7 +1936,7 @@ static int connect_handler(worker_st * ws)
 		gettime(&tnow);
 
 		if (periodic_check
-		    (ws, ws->proto_overhead + ws->crypto_overhead, tnow.tv_sec,
+		    (ws, ws->proto_overhead + ws->crypto_overhead, &tnow,
 		     ws->config->dpd) < 0) {
 			terminate_reason = REASON_ERROR;
 			goto exit;
