@@ -6,6 +6,7 @@ fi
 
 . ./common.sh
 
+ECHO_E="/bin/echo -e"
 if test -x /usr/bin/lockfile-create;then
 LOCKFILE="lockfile-create docker"
 UNLOCKFILE="lockfile-remove docker"
@@ -38,6 +39,61 @@ if test -z $FEDORA && test -z $DEBIAN;then
 	exit 77
 fi
 
+check_for_file() {
+	FILENAME=$1
+	IMG=$2
+
+	if test -z "$IMG"; then
+		IMG=$IMAGE_NAME
+	fi
+
+	rm -f out$TMP
+	$DOCKER exec $IMG ls $FILENAME >out$TMP
+	grep "$FILENAME" out$TMP|grep -v "cannot access"
+	if test $? != 0;then
+		echo "could not find $FILENAME"
+		return 1
+	else
+		rm -f out$TMP
+		return 0
+	fi
+}
+
+retrieve_user_info() {
+	USERNAME=$1
+	MATCH=$2
+	counter=0
+	ret=1
+
+	while [ $counter -lt 4 ]
+	do
+		$DOCKER exec $IMAGE_NAME occtl show user $USERNAME >out$TMP 2>&1
+		if test -z "$MATCH";then
+			grep "Username" out$TMP
+		else
+			grep "$MATCH" out$TMP
+		fi
+		ret=$?
+		if test $ret = 0;then
+			break
+		fi
+		counter=`expr $counter + 1`
+		sleep 2
+	done
+	if test $ret != 0;then
+		kill $PID
+		cat out$TMP
+		echo "could not find user information"
+		stop
+	else
+		rm -f out$TMP
+	fi
+}
+
+retrieve_route_info() {
+	retrieve_user_info $1 $2
+}
+
 stop() {
 	$DOCKER stop $IMAGE_NAME
 	$DOCKER rm $IMAGE_NAME
